/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "PerforceActionDirs.h"
#import "PerforceOutputParsers.h"
#import "AppUtils.h"
#import "AppDefaults.h"


@implementation PerforceActionDirs

+ (void) defaultRunFor:(id)owner selector:(SEL)aSelector withPath:(NSString*)dirPath
{
	PerforceActionDirs* action = [[[PerforceActionDirs init] alloc] autorelease];
	
	[action runFor:owner selector:aSelector withPath:dirPath];
}

- (void) dealloc
{
	[fOwner release];
	[fDirs release];
	
	[super dealloc];
}

- (void) runFor:(id)owner selector:(SEL)aSelector withPath:(NSString*)dirPath
{
    BOOL showEntireDepot  = [[AppDefaults defaultAppDefaults] getShowEntireDepot];
    BOOL showDeletedFiles = [[AppDefaults defaultAppDefaults] getShowDeletedFiles];

    NSMutableArray* commandAndArgs = [[[NSMutableArray alloc] init] autorelease];
	
	fOwner    = [owner retain];
	fSelector = aSelector;

	[commandAndArgs addObject:@"dirs"];
	
    if ( !showEntireDepot )
    {
		[commandAndArgs addObject:@"-C"];
    }
    
    if ( showDeletedFiles )
    {
		[commandAndArgs addObject:@"-D"];
    }
    
	[commandAndArgs addObject:dirPath];
    
	[self runAction:commandAndArgs stdInString:nil readToEOF:YES];
}

- (NSArray*) getDirs
{
	return fDirs;
}

- (void) processOutput: (NSString*) perforceOutput
{
	fDirs = [[PerforceOutputParsers parseDirsOutput:perforceOutput] retain];
}

static NSString* kNoSuchFile = @"no such file";

- (void) processError: (NSString*) perforceOutput
{
	NSRange nsRange = [perforceOutput rangeOfString:kNoSuchFile];

	if ( nsRange.location == NSNotFound )
	{
		SendErrorMessage ([perforceOutput cString]);
	}
}

@end
